==> appmesh-1.93.0-sources.jar: software/amazon/awscdk/services/appmesh/VirtualGatewayBaseProps.java <==
package software.amazon.awscdk.services.appmesh;

/**
 * (experimental) Basic configuration properties for a VirtualGateway.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:47:05.107Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.appmesh.$Module.class, fqn = "@aws-cdk/aws-appmesh.VirtualGatewayBaseProps")
@software.amazon.jsii.Jsii.Proxy(VirtualGatewayBaseProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface VirtualGatewayBaseProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Access Logging Configuration for the VirtualGateway.
     * <p>
     * Default: - no access logging
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.appmesh.AccessLog getAccessLog() {
        return null;
    }

    /**
     * (experimental) Default Configuration Virtual Node uses to communicate with Virtual Service.
     * <p>
     * Default: - No Config
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.appmesh.ClientPolicy getBackendsDefaultClientPolicy() {
        return null;
    }

    /**
     * (experimental) Listeners for the VirtualGateway.
     * <p>
     * Only one is supported.
     * <p>
     * Default: - Single HTTP listener on port 8080
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.appmesh.VirtualGatewayListener> getListeners() {
        return null;
    }

    /**
     * (experimental) Name of the VirtualGateway.
     * <p>
     * Default: - A name is automatically determined
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getVirtualGatewayName() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link VirtualGatewayBaseProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link VirtualGatewayBaseProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<VirtualGatewayBaseProps> {
        private software.amazon.awscdk.services.appmesh.AccessLog accessLog;
        private software.amazon.awscdk.services.appmesh.ClientPolicy backendsDefaultClientPolicy;
        private java.util.List<software.amazon.awscdk.services.appmesh.VirtualGatewayListener> listeners;
        private java.lang.String virtualGatewayName;

        /**
         * Sets the value of {@link VirtualGatewayBaseProps#getAccessLog}
         * @param accessLog Access Logging Configuration for the VirtualGateway.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder accessLog(software.amazon.awscdk.services.appmesh.AccessLog accessLog) {
            this.accessLog = accessLog;
            return this;
        }

        /**
         * Sets the value of {@link VirtualGatewayBaseProps#getBackendsDefaultClientPolicy}
         * @param backendsDefaultClientPolicy Default Configuration Virtual Node uses to communicate with Virtual Service.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder backendsDefaultClientPolicy(software.amazon.awscdk.services.appmesh.ClientPolicy backendsDefaultClientPolicy) {
            this.backendsDefaultClientPolicy = backendsDefaultClientPolicy;
            return this;
        }

        /**
         * Sets the value of {@link VirtualGatewayBaseProps#getListeners}
         * @param listeners Listeners for the VirtualGateway.
         *                  Only one is supported.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder listeners(java.util.List<? extends software.amazon.awscdk.services.appmesh.VirtualGatewayListener> listeners) {
            this.listeners = (java.util.List<software.amazon.awscdk.services.appmesh.VirtualGatewayListener>)listeners;
            return this;
        }

        /**
         * Sets the value of {@link VirtualGatewayBaseProps#getVirtualGatewayName}
         * @param virtualGatewayName Name of the VirtualGateway.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder virtualGatewayName(java.lang.String virtualGatewayName) {
            this.virtualGatewayName = virtualGatewayName;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link VirtualGatewayBaseProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public VirtualGatewayBaseProps build() {
            return new Jsii$Proxy(accessLog, backendsDefaultClientPolicy, listeners, virtualGatewayName);
        }
    }

    /**
     * An implementation for {@link VirtualGatewayBaseProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements VirtualGatewayBaseProps {
        private final software.amazon.awscdk.services.appmesh.AccessLog accessLog;
        private final software.amazon.awscdk.services.appmesh.ClientPolicy backendsDefaultClientPolicy;
        private final java.util.List<software.amazon.awscdk.services.appmesh.VirtualGatewayListener> listeners;
        private final java.lang.String virtualGatewayName;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.accessLog = software.amazon.jsii.Kernel.get(this, "accessLog", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.AccessLog.class));
            this.backendsDefaultClientPolicy = software.amazon.jsii.Kernel.get(this, "backendsDefaultClientPolicy", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.ClientPolicy.class));
            this.listeners = software.amazon.jsii.Kernel.get(this, "listeners", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.VirtualGatewayListener.class)));
            this.virtualGatewayName = software.amazon.jsii.Kernel.get(this, "virtualGatewayName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final software.amazon.awscdk.services.appmesh.AccessLog accessLog, final software.amazon.awscdk.services.appmesh.ClientPolicy backendsDefaultClientPolicy, final java.util.List<? extends software.amazon.awscdk.services.appmesh.VirtualGatewayListener> listeners, final java.lang.String virtualGatewayName) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.accessLog = accessLog;
            this.backendsDefaultClientPolicy = backendsDefaultClientPolicy;
            this.listeners = (java.util.List<software.amazon.awscdk.services.appmesh.VirtualGatewayListener>)listeners;
            this.virtualGatewayName = virtualGatewayName;
        }

        @Override
        public final software.amazon.awscdk.services.appmesh.AccessLog getAccessLog() {
            return this.accessLog;
        }

        @Override
        public final software.amazon.awscdk.services.appmesh.ClientPolicy getBackendsDefaultClientPolicy() {
            return this.backendsDefaultClientPolicy;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.services.appmesh.VirtualGatewayListener> getListeners() {
            return this.listeners;
        }

        @Override
        public final java.lang.String getVirtualGatewayName() {
            return this.virtualGatewayName;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAccessLog() != null) {
                data.set("accessLog", om.valueToTree(this.getAccessLog()));
            }
            if (this.getBackendsDefaultClientPolicy() != null) {
                data.set("backendsDefaultClientPolicy", om.valueToTree(this.getBackendsDefaultClientPolicy()));
            }
            if (this.getListeners() != null) {
                data.set("listeners", om.valueToTree(this.getListeners()));
            }
            if (this.getVirtualGatewayName() != null) {
                data.set("virtualGatewayName", om.valueToTree(this.getVirtualGatewayName()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-appmesh.VirtualGatewayBaseProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            VirtualGatewayBaseProps.Jsii$Proxy that = (VirtualGatewayBaseProps.Jsii$Proxy) o;

            if (this.accessLog != null ? !this.accessLog.equals(that.accessLog) : that.accessLog != null) return false;
            if (this.backendsDefaultClientPolicy != null ? !this.backendsDefaultClientPolicy.equals(that.backendsDefaultClientPolicy) : that.backendsDefaultClientPolicy != null) return false;
            if (this.listeners != null ? !this.listeners.equals(that.listeners) : that.listeners != null) return false;
            return this.virtualGatewayName != null ? this.virtualGatewayName.equals(that.virtualGatewayName) : that.virtualGatewayName == null;
        }

        @Override
        public final int hashCode() {
            int result = this.accessLog != null ? this.accessLog.hashCode() : 0;
            result = 31 * result + (this.backendsDefaultClientPolicy != null ? this.backendsDefaultClientPolicy.hashCode() : 0);
            result = 31 * result + (this.listeners != null ? this.listeners.hashCode() : 0);
            result = 31 * result + (this.virtualGatewayName != null ? this.virtualGatewayName.hashCode() : 0);
            return result;
        }
    }
}

==> appmesh-1.182.0-sources.jar: software/amazon/awscdk/services/appmesh/VirtualGatewayBaseProps.java <==
package software.amazon.awscdk.services.appmesh;

/**
 * Basic configuration properties for a VirtualGateway.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * Mesh mesh;
 * VirtualGateway gateway = mesh.addVirtualGateway("gateway", VirtualGatewayBaseProps.builder()
 *         .accessLog(AccessLog.fromFilePath("/dev/stdout"))
 *         .virtualGatewayName("virtualGateway")
 *         .listeners(List.of(VirtualGatewayListener.http(HttpGatewayListenerOptions.builder()
 *                 .port(443)
 *                 .healthCheck(HealthCheck.http(HttpHealthCheckOptions.builder()
 *                         .interval(Duration.seconds(10))
 *                         .build()))
 *                 .build())))
 *         .build());
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:46.351Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.appmesh.$Module.class, fqn = "@aws-cdk/aws-appmesh.VirtualGatewayBaseProps")
@software.amazon.jsii.Jsii.Proxy(VirtualGatewayBaseProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface VirtualGatewayBaseProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Access Logging Configuration for the VirtualGateway.
     * <p>
     * Default: - no access logging
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.appmesh.AccessLog getAccessLog() {
        return null;
    }

    /**
     * Default Configuration Virtual Node uses to communicate with Virtual Service.
     * <p>
     * Default: - No Config
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.appmesh.BackendDefaults getBackendDefaults() {
        return null;
    }

    /**
     * Listeners for the VirtualGateway.
     * <p>
     * Only one is supported.
     * <p>
     * Default: - Single HTTP listener on port 8080
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.appmesh.VirtualGatewayListener> getListeners() {
        return null;
    }

    /**
     * Name of the VirtualGateway.
     * <p>
     * Default: - A name is automatically determined
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getVirtualGatewayName() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link VirtualGatewayBaseProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link VirtualGatewayBaseProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<VirtualGatewayBaseProps> {
        software.amazon.awscdk.services.appmesh.AccessLog accessLog;
        software.amazon.awscdk.services.appmesh.BackendDefaults backendDefaults;
        java.util.List<software.amazon.awscdk.services.appmesh.VirtualGatewayListener> listeners;
        java.lang.String virtualGatewayName;

        /**
         * Sets the value of {@link VirtualGatewayBaseProps#getAccessLog}
         * @param accessLog Access Logging Configuration for the VirtualGateway.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder accessLog(software.amazon.awscdk.services.appmesh.AccessLog accessLog) {
            this.accessLog = accessLog;
            return this;
        }

        /**
         * Sets the value of {@link VirtualGatewayBaseProps#getBackendDefaults}
         * @param backendDefaults Default Configuration Virtual Node uses to communicate with Virtual Service.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder backendDefaults(software.amazon.awscdk.services.appmesh.BackendDefaults backendDefaults) {
            this.backendDefaults = backendDefaults;
            return this;
        }

        /**
         * Sets the value of {@link VirtualGatewayBaseProps#getListeners}
         * @param listeners Listeners for the VirtualGateway.
         *                  Only one is supported.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder listeners(java.util.List<? extends software.amazon.awscdk.services.appmesh.VirtualGatewayListener> listeners) {
            this.listeners = (java.util.List<software.amazon.awscdk.services.appmesh.VirtualGatewayListener>)listeners;
            return this;
        }

        /**
         * Sets the value of {@link VirtualGatewayBaseProps#getVirtualGatewayName}
         * @param virtualGatewayName Name of the VirtualGateway.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder virtualGatewayName(java.lang.String virtualGatewayName) {
            this.virtualGatewayName = virtualGatewayName;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link VirtualGatewayBaseProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public VirtualGatewayBaseProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link VirtualGatewayBaseProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements VirtualGatewayBaseProps {
        private final software.amazon.awscdk.services.appmesh.AccessLog accessLog;
        private final software.amazon.awscdk.services.appmesh.BackendDefaults backendDefaults;
        private final java.util.List<software.amazon.awscdk.services.appmesh.VirtualGatewayListener> listeners;
        private final java.lang.String virtualGatewayName;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.accessLog = software.amazon.jsii.Kernel.get(this, "accessLog", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.AccessLog.class));
            this.backendDefaults = software.amazon.jsii.Kernel.get(this, "backendDefaults", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.BackendDefaults.class));
            this.listeners = software.amazon.jsii.Kernel.get(this, "listeners", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.VirtualGatewayListener.class)));
            this.virtualGatewayName = software.amazon.jsii.Kernel.get(this, "virtualGatewayName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.accessLog = builder.accessLog;
            this.backendDefaults = builder.backendDefaults;
            this.listeners = (java.util.List<software.amazon.awscdk.services.appmesh.VirtualGatewayListener>)builder.listeners;
            this.virtualGatewayName = builder.virtualGatewayName;
        }

        @Override
        public final software.amazon.awscdk.services.appmesh.AccessLog getAccessLog() {
            return this.accessLog;
        }

        @Override
        public final software.amazon.awscdk.services.appmesh.BackendDefaults getBackendDefaults() {
            return this.backendDefaults;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.services.appmesh.VirtualGatewayListener> getListeners() {
            return this.listeners;
        }

        @Override
        public final java.lang.String getVirtualGatewayName() {
            return this.virtualGatewayName;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAccessLog() != null) {
                data.set("accessLog", om.valueToTree(this.getAccessLog()));
            }
            if (this.getBackendDefaults() != null) {
                data.set("backendDefaults", om.valueToTree(this.getBackendDefaults()));
            }
            if (this.getListeners() != null) {
                data.set("listeners", om.valueToTree(this.getListeners()));
            }
            if (this.getVirtualGatewayName() != null) {
                data.set("virtualGatewayName", om.valueToTree(this.getVirtualGatewayName()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-appmesh.VirtualGatewayBaseProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            VirtualGatewayBaseProps.Jsii$Proxy that = (VirtualGatewayBaseProps.Jsii$Proxy) o;

            if (this.accessLog != null ? !this.accessLog.equals(that.accessLog) : that.accessLog != null) return false;
            if (this.backendDefaults != null ? !this.backendDefaults.equals(that.backendDefaults) : that.backendDefaults != null) return false;
            if (this.listeners != null ? !this.listeners.equals(that.listeners) : that.listeners != null) return false;
            return this.virtualGatewayName != null ? this.virtualGatewayName.equals(that.virtualGatewayName) : that.virtualGatewayName == null;
        }

        @Override
        public final int hashCode() {
            int result = this.accessLog != null ? this.accessLog.hashCode() : 0;
            result = 31 * result + (this.backendDefaults != null ? this.backendDefaults.hashCode() : 0);
            result = 31 * result + (this.listeners != null ? this.listeners.hashCode() : 0);
            result = 31 * result + (this.virtualGatewayName != null ? this.virtualGatewayName.hashCode() : 0);
            return result;
        }
    }
}
